metaknowledge
=============

*metaknowledge* is a Python3 library that simplifies bibliometric
research using data from various sources. It reads a directory of plain
text files containing meta-data on publications and citations, and
writes to a variety of data structures that are suitable for
quantitative, network, and text analyses. It handles large datasets
(e.g. several million records) efficiently.

The website can be found at
`networkslab.org/metaknowledge <http://networkslab.org/metaknowledge/>`__.

Installing
----------

To install run ``python3 setup.py install``

For information on alternate installs read the documentation at the
`website <http://networkslab.org/metaknowledge/installation/>`__.
